@@ -7,6 +7,13 @@ from .exceptions import (AccountMuted, AccountNotFound, InvaildArgument,
 from .context import enter_context
 import inspect
 
+def applicationContextManager(func):
+    def wrapper(self, *args, **kwargs):
+        with enter_context(self):
+            return func(self, *args, **kwargs)
+    wrapper.__annotations__ = func.__annotations__
+    return wrapper
+
 def requireAuthenticated(func):
     def wrapper(self, *args, **kwargs):
         if not self.connect_info.sessionKey:
@@ -93,4 +100,9 @@ def context_enter_auto(context):
             with context:
                 return func(*args, **kwargs)
         return wrapper2
-    return wrapper1
\ No newline at end of file
+    return wrapper1
+
+def call_atonce(*args, **kwargs):
+    def wrapper(callable_target):
+        return callable_target(*args, **kwargs)
+    return wrapper
\ No newline at end of file
